@@ -6,7 +6,7 @@
  *
  * @if copyright
  *
- * Copyright (C) 2009, 2010 Aleix Conchillo Flaque
+ * Copyright (C) 2009-2014 Aleix Conchillo Flaque
  *
  * SCEW is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -74,6 +74,17 @@ static XML_Char const *TEST_STREAM_XML =
       "   <element attribute1=\"value1\" attribute2=\"value2\"/>\n"
       "</test>\n");
 
+/* Note that we don't have an XML header here. */
+static XML_Char const *TEST_STREAM_1_XML =
+  _XT("<test>\n"
+      "   <element>element contents</element>\n"
+      "   <element");
+
+static XML_Char const *TEST_STREAM_2_XML =
+  _XT("\n"
+      " attribute1=\"value1\" attribute2=\"value2\"/>\n"
+      "</test>\n");
+
 static XML_Char const *TEST_INVALID_XML =
   _XT("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n\n"
       "<test>\n"
@@ -239,6 +250,46 @@ START_TEST (test_load_stream)
 }
 END_TEST
 
+static scew_bool
+tree_chunked_stream_hook_ (scew_parser *parser, void *tree, void *user_data)
+{
+  static unsigned int const N_CHILDREN = 2;
+
+  scew_element *root = scew_tree_root (tree);
+
+  CHECK_U_INT (scew_element_count (root), N_CHILDREN,
+               "Number of children do not match");
+
+  return SCEW_TRUE;
+}
+
+START_TEST (test_load_chunked_stream)
+{
+  scew_parser *parser = scew_parser_create ();
+
+  scew_reader *reader_1 =
+    scew_reader_buffer_create (TEST_STREAM_1_XML,
+                               scew_strlen (TEST_STREAM_1_XML));
+
+  scew_reader *reader_2 =
+    scew_reader_buffer_create (TEST_STREAM_2_XML,
+                               scew_strlen (TEST_STREAM_2_XML));
+
+  scew_parser_set_element_hook (parser, element_hook_, NULL);
+  scew_parser_set_tree_hook (parser, tree_chunked_stream_hook_, NULL);
+
+  CHECK_BOOL (scew_parser_load_stream (parser, reader_1), SCEW_TRUE,
+              "Unable to parse first stream");
+
+  CHECK_BOOL (scew_parser_load_stream (parser, reader_2), SCEW_TRUE,
+              "Unable to parse second stream");
+
+  scew_reader_free (reader_1);
+  scew_reader_free (reader_2);
+  scew_parser_free (parser);
+}
+END_TEST
+
 
 /* Load invalid */
 
@@ -284,6 +335,7 @@ parser_suite (void)
   tcase_add_test (tc_core, test_load);
   tcase_add_test (tc_core, test_load_hooks);
   tcase_add_test (tc_core, test_load_stream);
+  tcase_add_test (tc_core, test_load_chunked_stream);
   tcase_add_test (tc_core, test_load_invalid);
   suite_add_tcase (s, tc_core);
 
